@@ -86,6 +86,7 @@ class PDBParser:
                 except KeyError:
                     corrected_pdb = ''.join(model_dict[1])
                     corrected_lines = model_dict[1]
+                    config.MODEL = 1
                     logger.warning('invalid model number specified, using first model instead')
             else:
                 corrected_pdb = self.pdbpath
@@ -1407,7 +1408,9 @@ class PDBComplex:
 
         if config.DNARECEPTOR:
             self.resis = [obres for obres in pybel.ob.OBResidueIter(
-                self.protcomplex.OBMol) if obres.GetName() in config.DNA + config.RNA]
+                self.protcomplex.OBMol) if obres.GetName() in config.DNA + config.RNA
+                ] + [obres for obres in pybel.ob.OBResidueIter(
+                    self.protcomplex.OBMol) if obres.GetResidueProperty(0)]
         else:
             self.resis = [obres for obres in pybel.ob.OBResidueIter(
                 self.protcomplex.OBMol) if obres.GetResidueProperty(0)]
